# IMAGE1 = 'tests/images/ac.png'
# IMAGE2 = 'tests/images/bc.png'
# IMAGE3 = 'tests/images/bb.jpg'
# HEIGHT = 512
# WIDTH = 512
# INFILE = 'tests/test_input.csv'
# OUTFILE = 'tests/test_output.csv'

image1 = 'tests/images/ac.png'
image2 = 'tests/images/bc.png'
image3 = 'tests/images/bb.jpg'
height = 512
width = 512
infile = 'tests/test_input.csv'
outfile = 'tests/test_output.csv'